@@ -35,10 +35,10 @@ class Config {
 private:
 
   static char* token[];   // config file tokens array.
-  void*        param[14]; // parameter pointer array.
+  void*        param[15]; // parameter pointer array.
 
   // formats to scan/print tokens from/to the config file.
-  char*        format;
+  static const char* format;
 
 public:
   
@@ -51,6 +51,8 @@ public:
 
   FLT          ROOT_FREQUENCY_ERROR; // deviation of the above root frequency.
 
+  FLT          MIN_FREQUENCY; // minimum valid frequency.
+
   unsigned int FFT_SIZE; // number of samples of the FFT.
 
   FLT          CALCULATION_RATE;
@@ -67,7 +69,7 @@ public:
   FLT          NOISE_THRESHOLD;    // dB
   FLT          NOISE_THRESHOLD_UN; // natural units (internal parameter)
 
-  // frequency guessing algorithm configuration
+  // frequency finding algorithm configuration
   //-------------------------------------------
 
   unsigned int PEAK_NUMBER; // number of maximum peaks considered.
@@ -104,9 +106,8 @@ public:
   void reset();
 
   // derivate internal parameters from external ones.
-  void updateInternalParameters();
+  bool updateInternalParameters();
 
-  void asociaAtributos();
   void saveConfigFile(char* archivo);
   void parseConfigFile(char* archivo);
 };
